@@ -3,7 +3,6 @@ from typing import Iterable, List, Optional, Tuple, Union, Dict
 import re
 import hashlib
 import pandas as pd
-import pandas_market_calendars as mcal
 
 from toolbox.db.api.sql_connection import SQLConnection
 from toolbox.db.read.etf_universe import ETFUniverse
@@ -15,6 +14,12 @@ try:
 except ImportError as e:
     pass
 
+# this allows compatibility with python 3.6
+try:
+    import pandas_market_calendars as mcal
+except ImportError as e:
+    pass
+
 
 class QueryConstructor:
     """
@@ -96,7 +101,7 @@ class QueryConstructor:
         makes the changes to the dataframe query specified by self._df_options
         :param raw_df: the dataframe we are applying the changes to
         """
-        if self._df_options['freq']:
+        if self._df_options['freq'] and 'date' in raw_df.columns:
             raw_df['date'] = raw_df['date'].dt.to_period(self._df_options['freq'])
 
         raw_df = raw_df.set_index(self._df_options['index']) if self._df_options['index'] else raw_df
@@ -119,7 +124,7 @@ class QueryConstructor:
             else:
                 raise ValueError('Unknown type to regester asset table')
 
-    def query_timeseries_table(self, table: str, fields: List[str], assets: Optional[Union[List[any], str]],
+    def query_timeseries_table(self, table: str, fields: List[str], assets: Union[Iterable[any], str],
                                search_by: str, start_date: str, end_date: str = '3000', adjust: bool = True):
         """
         constructs a query to get timeseries data from the database
@@ -130,7 +135,7 @@ class QueryConstructor:
         :param start_date: the first date to get data on in '%Y-%m-%d' format
         :param end_date: the last date to get data on in '%Y-%m-%d' format
         :param adjust: should we adjust the pricing?
-        :return: Pandas Dataframe Columns: fields; Index: ('date', search_by)
+        :return: self
         """
 
         self._query_string['select'] = self._create_columns_to_select_sql(table=table,
@@ -150,7 +155,7 @@ class QueryConstructor:
 
         return self
 
-    def query_static_table(self, table: str, fields: List[str], assets: Optional[Union[List[any], str]],
+    def query_static_table(self, table: str, fields: List[str], assets: Union[Iterable[any], str],
                            search_by: str, start_date: str = '1900', end_date: str = '3000'):
         """
         Reads static data fom the database.
@@ -162,23 +167,21 @@ class QueryConstructor:
         :param fields: the fields we are getting in our query
         :param start_date: the first date to get data on in '%Y-%m-%d' format, defaults to 1900
         :param end_date: the last date to get data on in '%Y-%m-%d' format, defaults to 3000
-        :return: Pandas Dataframe Columns: fields; Index: 'date', search_by
+        :return: self
         """
-        select_col_sql = self._create_columns_to_select_sql(table=table, fields=fields + ['date', search_by],
-                                                            adjust=False)
+        select_col_sql = self._create_columns_to_select_sql(table=table, fields=fields + [search_by], adjust=False)
         self._create_asset_filter_sql(assets=assets, search_by=search_by, start_date=start_date,
                                       end_date=end_date, timeseries_table=table)
 
-        self._query_string['select'] = f"""{select_col_sql}, min(data.date) AS min_date, max(data.date) AS max_data"""
-        self._query_string['from'] = f"""{table} AS data {self._asset_table} AS uni 
+        self._query_string['select'] = f"""{select_col_sql}, min(data.date) AS min_date, max(data.date) AS max_date"""
+        self._query_string['from'] = f"""{table} AS data JOIN {self._asset_table} AS uni 
                                         ON uni.{search_by} = data.{search_by}"""
         self._query_string['where'] = f"""data.date >= '{start_date}' AND data.date <= '{end_date}'"""
         self._query_string['group_by'] = select_col_sql
 
         self._df_options['index'] = [search_by]
         self._query_metadata['asset_id'] = search_by
-        self._query_metadata['fields'] = fields
-        self.set_freq(None)
+        self._query_metadata['fields'] = fields + ['min_date', 'max_date']
 
         return self
 
@@ -192,18 +195,16 @@ class QueryConstructor:
         :param end_date: last date to query on
         :param index: what should the index of the returned frame be
         :param keep_date_col: should the date column be returned?
-        :return: Pandas Dataframe Columns: fields; Index: 'date', fields
+        :return: self
         """
         query_fields = fields
         if keep_date_col:
             query_fields += ['date']
 
-        table = ETFUniverse().get_universe_path_parse(table) if 'ETF' in table else f"universe.{table}"
-
         select_col_sql = self._create_columns_to_select_sql(fields=query_fields, adjust=False, tbl_alias='')
 
         self._query_string['select'] = select_col_sql
-        self._query_string['from'] = (ETFUniverse().get_universe_path_parse(table) if 'ETF' in table
+        self._query_string['from'] = (f"'{ETFUniverse().get_universe_path_parse(table)}'" if 'ETF' in table
                                       else f"universe.{table}")
         self._query_string['where'] = f"""date >= '{start_date}' AND date <= '{end_date}'"""
 
@@ -212,6 +213,29 @@ class QueryConstructor:
 
         return self
 
+    def query_no_date_table(self, table: str, fields: List[str], assets: Union[Iterable[any], str],
+                            search_by: str):
+        """
+        get data from a table with no date column
+        :param table: the table we are searching must be prefixed by the schema
+        :param fields: fields to pull from the table
+        :param assets: the assets we want to get data for, or a universe table
+        :param search_by: the identifier we are searching by
+        :return: self
+        """
+        select_col_sql = self._create_columns_to_select_sql(table=table, fields=fields + [search_by], adjust=False)
+        self._create_asset_filter_sql(assets=assets, search_by=search_by)
+
+        self._query_string['select'] = select_col_sql
+        self._query_string['from'] = f"""{table} AS data JOIN {self._asset_table} AS uni 
+                                                ON uni.{search_by} = data.{search_by}"""
+
+        self._df_options['index'] = [search_by]
+        self._query_metadata['asset_id'] = search_by
+        self._query_metadata['fields'] = fields + ['min_date', 'max_date']
+        return self
+
+
     def distinct(self):
         """
         will make add a distinct keyword to the select clause of a query
@@ -413,18 +437,24 @@ class QueryConstructor:
 
         return self
 
-    def nest(self, rewrite_select: bool = True):
+    def nest(self, rewrite_select: bool = True, include_date=True):
         """
         will nest the current sql statement in to the from clause
         and will name the table data
         :param rewrite_select: should we make the default select statement or leave the select statement blank?
+        :param include_date: should we include date in the select statement
         """
         self._query_string['from'] = f""" ({self.raw_sql}) AS data """
         self._clear_query_string(['from'])
 
+        fields = self._query_metadata['fields'] + [self._query_metadata['asset_id']]
+
+        if include_date:
+            fields.append('date')
+
         if rewrite_select:
-            self._query_string['select'] = self._create_columns_to_select_sql(
-                fields=self._query_metadata['fields'] + [self._query_metadata['asset_id'], 'date'], adjust=False)
+            self._query_string['select'] = self._create_columns_to_select_sql(fields=fields, adjust=False)
+
         return self
 
     def where(self, where_condition: str):
@@ -523,8 +553,8 @@ class QueryConstructor:
         end_date = re.compile("data\.date <= ([^\s]+)").search(searching).group(1).replace('\'', '')
         return start_date, end_date
 
-    def _create_asset_filter_sql(self, assets: Union[List[Union[int, str]], str], search_by: str, start_date: str,
-                                 end_date: str, timeseries_table: str = None) -> None:
+    def _create_asset_filter_sql(self, assets: Union[List[Union[int, str]], str], search_by: str,
+                                 start_date: str = None, end_date: str = None, timeseries_table: str = None) -> None:
         """
         Sets the self._asset_table to the table name of thew table containing the assets
         param assets: the assets we want to get data for, or a universe table
@@ -538,7 +568,7 @@ class QueryConstructor:
 
         asset_table = f'universe.{assets}'
         # checking to see if the user wants all columns
-        if assets == '*':
+        if isinstance(assets, str) and assets == '*':
             if timeseries_table is None:
                 raise ValueError('Must pass a timeseries_table if assets = \'*\'')
 
@@ -561,14 +591,9 @@ class QueryConstructor:
                         WHERE date >= '{start_date}' AND date <= '{end_date}')"""
             tbl_name = f'temp.{tbl_name}'
 
-        # user passes a seris of assets as universe
-        elif isinstance(assets, pd.Series):
-            tbl_name = '_' + pd.util.hash_pandas_object(assets)
-            table = assets.to_frame(search_by)
-
-        # user passes a list of assets as universe
-        elif isinstance(assets, List):
-            tbl_name = '_' + hashlib.sha224(str(assets).encode('utf-8')).hexdigest()
+        # We have an iterable of assets
+        elif isinstance(assets, Iterable):
+            tbl_name = '_' + hashlib.sha224(str(list(assets)).encode('utf-8')).hexdigest()
             table = pd.DataFrame(assets, columns=[search_by])
 
         # dont know what the user passed raise an error
