@@ -17,7 +17,7 @@ def rebuild_db(drop: bool = False):
             'schema': 'ccm',
             'file_path': '/Users/alex/Desktop/WRDS/CRSP/Annual Update/CRSP:Compustst Merged/Compustat CRSP Link/rc9ie3efp9e3opdf.csv',
             'custom': """
-                        UPDATE ccm.crsp_cstat_link SET LINKENDDT=99991231 WHERE LINKENDDT = 'E';
+                        UPDATE ccm.crsp_cstat_link SET LINKENDDT=20501231 WHERE LINKENDDT = 'E';
                       """,
             'alter_type': {'LINKDT': ['timestamp', '%Y%m%d'],
                            'LINKENDDT': ['timestamp', '%Y%m%d'],
@@ -105,9 +105,9 @@ def rebuild_db(drop: bool = False):
             'schema': 'crsp',
             'file_path': '/Users/alex/Desktop/WRDS/CRSP/Quarterly Update/Mutual Fund/Portfolio Holdings/Portfolio Holdings 200101-202109.gz',
             # 'where': """ crsp_portno in (SELECT distinct crsp_portno FROM crsp.fund_summary) """,
-            'rename': {'eff_dt': 'date'},
+            'rename': {'report_dt': 'date'},
             'alter_type': {'date': ['timestamp', '%Y%m%d'],
-                           'report_dt': ['timestamp', '%Y%m%d'],
+                           'eff_dt': ['timestamp', '%Y%m%d'],
                            'maturity_dt': ['timestamp', '%Y%m%d']},
             'index': [{'name': 'crsp_mfph_date_idx', 'column': 'date'},
                       {'name': 'crsp_mfph_crsp_portno_idx', 'column': 'crsp_portno'},
@@ -159,7 +159,7 @@ def rebuild_db(drop: bool = False):
         },
 
         #
-        # WRDS Financial Ratios
+        # WRDS
         #
 
         {
@@ -176,6 +176,19 @@ def rebuild_db(drop: bool = False):
                  {'name': 'wrds_firm_permno_idx', 'column': 'permno'},
                  {'name': 'wrds_firm_gvkey_idx', 'column': 'gvkey'}]
         },
+        {
+            'rows_to_interpret': 50_000,
+            'schema': 'wrds',
+            'table': 'subsidiary',
+            'file_path': '/Users/alex/Desktop/WRDS/Subsidary Data By WRDS/Company Subsidiaries/WRDS Company Subidiary Data (Beta) 199312-202004.gz',
+            'rename': {'SECPDATE': 'date'},
+            'alter_type': {'FDATE': ['timestamp', '%Y%m%d'],
+                           'RDATE': ['timestamp', '%Y%m%d'],
+                           'date': ['timestamp', '%Y%m%d']},
+            'index':
+                [{'name': 'wrds_sub_date_idx', 'column': 'date'},
+                 {'name': 'wrds_sub_gvkey_idx', 'column': 'gvkey'}]
+        },
 
         #
         # IBES
@@ -239,6 +252,23 @@ def rebuild_db(drop: bool = False):
                       {'name': 'ibes_ss_usfirm_idx', 'column': 'usfirm'},
                       {'name': 'ibes_ss_measure_idx', 'column': 'measure'},
                       {'name': 'ibes_ss_fpi_idx', 'column': 'fpi'}]
+        },
+
+        #
+        # Audit Analytics
+        #
+        {
+            'rows_to_interpret': 500000,
+            'table': 'audit_opinions',
+            'schema': 'aa',
+            'file_path': '/Users/alex/Desktop/WRDS/Audit Analytics/Audit Opinions/lbsyljuigehonvhr.csv',
+            'rename': {'FILE_ACCEPTED': 'date',
+                       'COMPANY_FKEY': 'cik'},
+            'alter_type': {'DATE': ['timestamp', '%Y%m%d'],
+                           # 'FISCAL_YEAR_ENDED_OF_OPINION': ['timestamp', '%Y%m%d']
+                           },
+            'index': [{'name': 'aa_ss_date_idx', 'column': 'date'},
+                      {'COMPANY_FKEY': 'aa_ss_ticker_idx', 'column': 'cik'}]
         }
     ]
 
